@@ -22,21 +22,22 @@ import glob
 import os
 import sys
 
-
+import nowplaying.players
 
 def _get_players():
-	cwd = __path__[0]
+	players_path = nowplaying.players.__path__[0]
+	
 	players = []
 	
-	for path in glob.glob(cwd + "/*"):
+	for path in glob.glob(players_path + "/*.py"):
 		
 		name = os.path.basename(path)[:-3]
 		if name.startswith("__"): continue
 		
-		full_name = "%s.%s" %(__package__, name)
+		full_name = "%s.players.%s" %(__package__, name)
 		
 		if not full_name in sys.modules.keys():
-			imp.load_module(full_name, *imp.find_module(name, [cwd]))
+			imp.load_module(full_name, *imp.find_module(name, [players_path]))
 		
 		players.append(sys.modules[full_name].Player())
 	
